@@ -245,6 +245,7 @@ class ApiDefV4(object):
         self.apiParams = []
         self.apiResps = []
         self.apiAlias = []
+        self.iswildcard = False # test.* -> "test/*"
 
     def __repr__(self):
         txt = '%s %s %s # %s\n' % (self.api, self.method, self.auth, self.comment)
@@ -257,6 +258,9 @@ class ApiDefV4(object):
         if '.' in self.api:
             _items = self.api.split('.')
             assert_error(len(_items) >= 2, '无效的api名称定义', self.lineno, self.line)
+            if _items[-1] == '*': # wildcard
+               self.iswildcard = True
+               _items = _items[:-1]
             return ''.join(map(lambda x: upperFirst(x), _items))
         return upperFirst(self.api)
 
@@ -266,7 +270,6 @@ class ApiDefV4(object):
 
     def apiRouterName(self):
         if '.' in self.api:
-            _items = self.api.split('.')
             return self.api.replace('.', '/')
         return self.api
 
