@@ -37,7 +37,7 @@ class SwaggerSchema(object):
             d['required'] = self.required
 
         dp = {}
-        for k, v in self.properties.iteritems():
+        for k, v in self.properties.items(): # py2 vs py3
             dp[k] = v.todict()
         if len(dp) > 0:
             d['properties'] = dp
