@@ -7,6 +7,7 @@ import glob
 from .apimodel import ApiModel, ApiDef
 from .objmodel import ObjModel
 from .conf import Color, MOD
+from .helper import IS_PY3
 
 # OpenAPI Swargger https://swagger.io/specification/v2
 
@@ -149,14 +150,14 @@ class Swagger(object):
         d = {'swagger': self.swaggerVersion, 'host': self.host, 'basePath': self.basePath}
         d['schemes'] = self.schemes
         dps = {}
-        for k, v in self.paths.iteritems():
+        for k, v in self.paths.items(): # py2 vs py3 
             dps[k] = v.todict()
         d['paths'] = dps
         dds = {}
-        for k, v in self.definitions.iteritems():
+        for k, v in self.definitions.items():
             dds[k] = v.todict()
         d['definitions'] = dds
-        d['tags'] = map(lambda x: x.todict(), self.tags)
+        d['tags'] = list(map(lambda x: x.todict(), self.tags)) # py2 vs py3
         if self.info:
             d['info'] = self.info.todict()
         return d
@@ -224,7 +225,7 @@ class SwaggerOperation(object):
         else:
             d['produces'] = ['application/json']
         if len(self.parameters) > 0:
-            d['parameters'] = map(lambda x: x.todict(), self.parameters)
+            d['parameters'] = list(map(lambda x: x.todict(), self.parameters))
         if len(self.responses) > 0:
             respd = {}
             for resp in self.responses:
@@ -270,7 +271,7 @@ class SwaggerParameter(object):
             # if self.format:
             #     d['format'] = self.format
             if len(self.items) > 0:
-                d['items'] = map(lambda x: x.todict(), self.items)
+                d['items'] = list(map(lambda x: x.todict(), self.items))
         if self.default:
             d['default'] = self.default
         return d
@@ -297,7 +298,7 @@ class SwaggerParameterItems(object):
             d['default'] = self.default
 
         if len(self.items) > 0:
-            d['items'] = map(lambda x: x.todict(), self.items)
+            d['items'] = list(map(lambda x: x.todict(), self.items)) # py2 vs py3
         return d
 
 
@@ -345,7 +346,7 @@ class SwaggerSchema(object):
             d['required'] = self.required
 
         dp = {}
-        for k, v in self.properties.iteritems():
+        for k, v in self.properties.items():
             dp[k] = v.todict()
         if len(dp) > 0:
             d['properties'] = dp
@@ -401,7 +402,7 @@ class SwaggerPropertie(object):
             d['additionalProperties'] = self.additionalProperties.todict()
         
         dp = {}
-        for k, v in self.properties.iteritems():
+        for k, v in self.properties.items():
             dp[k] = v.todict()
         if len(dp) > 0:
             d['properties'] = dp
@@ -571,7 +572,7 @@ def genSwaggerContent(url, title, description, version):
     infoPath = 'gopher/app/info/info.go'
     lines = open(infoPath).read().splitlines()
     ds = _getGoStruct(lines)
-    for item in ds.iteritems():
+    for item in ds.items(): # py2 vs py3
         name, props = item
         propItem = SwaggerPropertie(name, 'object', '', name, 'object', name)
 
@@ -599,6 +600,8 @@ def genSwaggerContent(url, title, description, version):
     
     # model defines
     lines = open('objmodel.txt', 'rb').readlines()
+    if IS_PY3(): # py2 vs py3
+        lines = list(map(lambda x: x.decode('utf-8'), lines))
     objModel = ObjModel.fromLines(lines)
     objModel.checkObjCode() 
     # obj
@@ -623,6 +626,8 @@ def genSwaggerContent(url, title, description, version):
 
     # api
     lines = open('apimodel.txt', 'rb').readlines()
+    if IS_PY3(): # py2 vs py3
+        lines = list(map(lambda x: x.decode('utf-8'), lines))
     apiModel = ApiModel.fromLines(lines)
     apiModel.initResps()
     for group in apiModel.groups:
@@ -697,8 +702,13 @@ def genSwaggerContent(url, title, description, version):
 def genSwaggerYaml(savePath, url, title, description, version):
     content = genSwaggerContent(url, title, description, version)
     fp = open(savePath, 'wb')
-    fp.write('# Code generated by m2c. DO NOT EDIT.\n')
-    fp.write(content)
+    header = '# Code generated by m2c. DO NOT EDIT.\n'
+    if IS_PY3():
+        fp.write(header.encode('utf-8'))
+        fp.write(content.encode('utf-8'))
+    else:
+        fp.write(header)
+        fp.write(content)
     fp.close()
 
 
@@ -718,7 +728,10 @@ const SWAGGER_CONTENT = `
 %s
 `
     ''' % (SWAGGER_INDEX, content)
-    fp.write(code)
+    if IS_PY3():
+        fp.write(code.encode('utf-8'))
+    else:
+        fp.write(code)
     fp.close()
     os.system('gofmt -w gopher/ak/gw')
 
@@ -738,7 +751,10 @@ const SWAGGER_CONTENT = `
 %s
 `
     ''' % (SWAGGER_INDEX, content)
-    fp.write(code)
+    if IS_PY3():
+        fp.write(code.encode('utf-8'))
+    else:
+        fp.write(code)
     fp.close()
     os.system('gofmt -w gopher/ak/gw')
 
@@ -754,7 +770,7 @@ def genSwaggerContentV4(url, title, description, version):
         lines = open(ip).read().splitlines()
         ds.update(_getGoStruct(lines))
 
-    for item in ds.iteritems():
+    for item in ds.items(): # py2 vs py3
         name, props = item
         propItem = SwaggerPropertie(name, 'object', '', name, 'object', name)
 
@@ -782,6 +798,8 @@ def genSwaggerContentV4(url, title, description, version):
     
     # model defines
     lines = open('objmodel.txt', 'rb').readlines()
+    if IS_PY3(): # py2 vs py3
+        lines = list(map(lambda x: x.decode('utf-8'), lines))
     objModel = ObjModel.fromLines(lines)
     objModel.checkObjCode() 
     # obj
@@ -806,6 +824,8 @@ def genSwaggerContentV4(url, title, description, version):
 
     # api
     lines = open('apimodel.txt', 'rb').readlines()
+    if IS_PY3(): # py2 vs py3
+        lines = list(map(lambda x: x.decode('utf-8'), lines))
     apiModel = ApiModel.fromLines(lines)
     apiModel.initResps()
     for group in apiModel.groups:
