@@ -37,11 +37,12 @@ vlogs = {
     '0.3.4': 'add python3 support',
     '0.3.5': 'fix swagger tags/servers',
     '0.3.6': 'add service code template',
-    '0.3.7': 'add cmdmodel'
+    '0.3.7': 'add cmdmodel',
+    '0.3.8': 'add wildcard router'
 }
 
 name = 'm2c'
-version = '0.3.7'
+version = '0.3.8'
 
 from .conf import M2C_PATH, Color
 from .helper import m2c_version
